#!/bin/sh

# Base directories for the engine and for the application server:
JBOSS_BASE=${JBOSS_BASE:-/usr/share/jboss-as}
ENGINE_BASE=${ENGINE_BASE:-/usr/share/ovirt-engine}

# Defaults for the heap size:
ENGINE_MIN_HEAP=${ENGINE_HEAP_MIN:-1g}
ENGINE_MAX_HEAP=${ENGINE_HEAP_MIN:-1g}

# Module path should include first the engine modules so that they can override
# those provided by the application server if needed:
ENGINE_MODULEPATH=${ENGINE_MODULEPATH:-${ENGINE_BASE}/modules:${JBOSS_BASE}/modules}

# Virtual machine options:
OPTIONS="-server"
OPTIONS="${OPTIONS} -XX:+UseCompressedOops"
OPTIONS="${OPTIONS} -XX:+TieredCompilation"
OPTIONS="${OPTIONS} -Xms${ENGINE_MIN_HEAP}"
OPTIONS="${OPTIONS} -Xms${ENGINE_MAX_HEAP}"
OPTIONS="${OPTIONS} -XX:MaxPermSize=256m"
OPTIONS="${OPTIONS} -Djava.net.preferIPv4Stack=true"
OPTIONS="${OPTIONS} -Dsun.rmi.dgc.client.gcInterval=3600000"
OPTIONS="${OPTIONS} -Dsun.rmi.dgc.server.gcInterval=3600000"
OPTIONS="${OPTIONS} -Djava.awt.headless=true"

# Application server options:
OPTIONS="${OPTIONS} -Dlogging.configuration=file:///etc/ovirt-engine/ovirt-engine-logging.properties"
OPTIONS="${OPTIONS} -Dorg.jboss.resolver.warning=true"
OPTIONS="${OPTIONS} -Djboss.modules.system.pkgs=org.jboss.byteman"
OPTIONS="${OPTIONS} -Djboss.server.default.config=ovirt-engine.xml"
OPTIONS="${OPTIONS} -Djboss.home.dir=${JBOSS_BASE}"
OPTIONS="${OPTIONS} -Djboss.server.base.dir=${ENGINE_BASE}"
OPTIONS="${OPTIONS} -Djboss.server.config.dir=/etc/ovirt-engine"
OPTIONS="${OPTIONS} -Djboss.server.data.dir=/var/lib/ovirt-engine"
OPTIONS="${OPTIONS} -Djboss.server.log.dir=/var/log/ovirt-engine"
OPTIONS="${OPTIONS} -Djboss.server.temp.dir=/var/cache/ovirt-engine"
OPTIONS="${OPTIONS} -Djboss.controller.temp.dir=/var/cache/ovirt-engine"

# Remove and recreate deployment markers:
/bin/rm -f ${ENGINE_BASE}/deployments/engine.ear.*
/bin/touch ${ENGINE_BASE}/deployments/engine.ear.dodeploy
/bin/rm -f ${ENGINE_BASE}/deployments/ROOT.war.*
/bin/touch ${ENGINE_BASE}/deployments/ROOT.war.dodeploy

# Start the java virtual machine:
exec /bin/java \
  ${OPTIONS} \
  -jar ${JBOSS_BASE}/jboss-modules.jar \
  -mp ${ENGINE_MODULEPATH} \
  -jaxpmodule javax.xml.jaxp-provider \
  org.jboss.as.standalone \
  -c ovirt-engine.xml
